@@ -57,6 +57,12 @@ def get_settings_schema(**kwargs):
                 one large file""",
                 "default": 10000,
             },
+            "chunk_multiplier": {
+                "type": "integer",
+                "description": """Number of records to send to the integration at one time. Set to 0 to combine into 
+                    one large file""",
+                "default": 100,
+            },
             "parallelize": {
                 "type": "boolean",
                 "description": """deliver data in parallel to speed up delivery""",
