@@ -19,11 +19,11 @@ def create_file_chunks(bucket_name, file_pattern, job_uuid, file_headers, integr
     if checkpoint is not None:
         chunk_number = checkpoint['chunk_number'] + 1
     chunk_file_path = ''
-    idx = None
+    line_number = None
     file_path = None
-    for row, idx, file_path in read_remote_csvs_as_stream(bucket_name=bucket_name, file_pattern=file_pattern,
-                                                          job_uuid=job_uuid,
-                                                          delimiter=delimiter):
+    for row, line_number, file_path in read_remote_csvs_as_stream(bucket_name=bucket_name, file_pattern=file_pattern,
+                                                                  job_uuid=job_uuid,
+                                                                  delimiter=delimiter):
         chunk_file_path, chunk_pointer, chunk_writer = add_row_to_chunk(
             job_uuid=job_uuid,
             file_headers=file_headers,
@@ -44,7 +44,7 @@ def create_file_chunks(bucket_name, file_pattern, job_uuid, file_headers, integr
             delivered_pointer = None
             yield chunk_file_path, delivered_file_path, chunk_number
             update_file_checkpoint(job_uuid=job_uuid, file_pattern=file_pattern, chunk_number=chunk_number,
-                                   line_number=idx, file_path=file_path)
+                                   line_number=line_number, file_path=file_path)
             start = datetime.utcnow().timestamp()
             os.remove(chunk_file_path)
             os.remove(delivered_file_path)
@@ -56,7 +56,7 @@ def create_file_chunks(bucket_name, file_pattern, job_uuid, file_headers, integr
         delivered_pointer.close()
         yield chunk_file_path, delivered_file_path, chunk_number
         update_file_checkpoint(job_uuid=job_uuid, file_pattern=file_pattern, chunk_number=chunk_number,
-                               line_number=idx, file_path=file_path)
+                               line_number=line_number, file_path=file_path)
         os.remove(chunk_file_path)
         os.remove(delivered_file_path)
 
@@ -137,7 +137,8 @@ def read_remote_csvs_as_stream(bucket_name, file_pattern, job_uuid, delimiter='|
 def update_file_checkpoint(job_uuid, file_pattern, file_path, chunk_number, line_number):
     from stratus_api.integrations.cache import cache_data
     key = generate_file_cache_key(file_pattern=file_pattern, job_uuid=job_uuid)
-    return cache_data(key=key, value=dict(file_path=file_path, chunk_number=chunk_number, line_number=line_number), expiration_seconds=86400)
+    return cache_data(key=key, value=dict(file_path=file_path, chunk_number=chunk_number, line_number=line_number),
+                      expiration_seconds=86400)
 
 
 def get_file_checkpoint(file_pattern, job_uuid):
@@ -158,7 +159,8 @@ def create_parallel_chunks(job_uuid, bucket_name, file_pattern, platform_name, d
     from stratus_api.integrations.distribution import compose_integration_logs, log_integration
     import os
     from datetime import datetime
-    chunk_multiplier = 100
+    import math
+    chunk_multiplier = get_integration_settings()['chunk_multiplier']
     chunk_size = get_integration_settings()['chunk_size'] * chunk_multiplier
     checkpoint = get_file_checkpoint(file_pattern=file_pattern, job_uuid=job_uuid)
     if checkpoint is not None:
@@ -187,20 +189,24 @@ def create_parallel_chunks(job_uuid, bucket_name, file_pattern, platform_name, d
 
         chunk_path, chunk_pointer, chunk_writer = add_to_file(path=chunk_path, row=row, headers=file_headers,
                                                               delimiter=delimiter, pointer=chunk_pointer,
-                                                              writer=chunk_writer)
+                                                              writer=chunk_writer, add_headers=False)
         if 0 < chunk_size <= chunk_records:
-            total_chunks = chunk_number + 1
-            chunk_pointer, chunk_number, chunk_records = push_chunks_to_distribute(
+            push_chunks_to_distribute(
                 chunk_pointer=chunk_pointer, chunk_multiplier=chunk_multiplier, chunk_path=chunk_path,
                 bucket_name=bucket_name, platform_name=platform_name,
                 job_uuid=job_uuid, segments=segments, destination=destination,
                 file_headers=file_headers, id_types=id_types, operations=operations,
                 chunk_number=chunk_number, start_time=start_time
             )
+            chunk_number += chunk_multiplier
             update_file_checkpoint(job_uuid=job_uuid, file_pattern=file_pattern, file_path=file_path,
                                    chunk_number=chunk_number, line_number=line_number)
+            chunk_records = 0
+            chunk_pointer = None
+
     if chunk_records > 0:
-        total_chunks = 1 if chunk_size == 0 else chunk_number + chunk_records / (chunk_size / chunk_multiplier)
+        total_chunks = 1 if chunk_size == 0 else chunk_number + math.ceil(
+            chunk_records / (chunk_size / chunk_multiplier))
         push_chunks_to_distribute(
             chunk_pointer=chunk_pointer, chunk_multiplier=chunk_multiplier, chunk_path=chunk_path,
             bucket_name=bucket_name, platform_name=platform_name,
@@ -209,12 +215,12 @@ def create_parallel_chunks(job_uuid, bucket_name, file_pattern, platform_name, d
             chunk_number=chunk_number, start_time=start_time
         )
     rows = compose_integration_logs(job_uuid, segments, file_pattern, int(start_time.timestamp()), id_types, operations,
-                                    'processed')
+                                    'completed')
     log_integration(rows)
     return dict(job_uuid=job_uuid, total_chunks=total_chunks)
 
 
-def push_chunks_to_distribute(chunk_pointer, chunk_path, chunk_multiplier, job_uuid, bucket_name,
+def push_chunks_to_distribute(chunk_pointer, chunk_path, job_uuid, bucket_name,
                               platform_name, start_time,
                               destination, file_headers, segments, id_types, operations, chunk_number, **kwargs):
     from stratus_api.integrations.tasks.distributions import deliver_data_task
@@ -236,8 +242,5 @@ def push_chunks_to_distribute(chunk_pointer, chunk_path, chunk_multiplier, job_u
                             start_time=start_time.timestamp(),
                             job_uuid=job_uuid, segments=segments, destination=destination, file_headers=file_headers,
                             id_types=id_types, operations=operations, chunk_start_number=chunk_number)
-    try:
-        os.remove(chunk_path)
-    except:
-        pass
-    return None, chunk_number * chunk_multiplier, 0
+    os.remove(chunk_path)
+    return True
